<?php

/*
Plugin Name: WooCommerce Conditional Shipping Dynamic Rates
Plugin URI:  https://wooelements.com
Description: Use dynamic shipping rates for WooCommerce Conditional Shipping Pro
Version:     2.0.0
Author:      Lauri Karisola / WooElements.com
Author URI:  https://wooelements.com
Text Domain: woo-conditional-shipping-dynamic-rates
Domain Path: /languages
WC requires at least: 3.0.0
WC tested up to: 4.0.1
*/

/**
 * Prevent direct access to the script.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Register all rates
 */
add_filter( 'woocommerce_package_rates', function( $rates, $package ) {
	$registered = get_option( 'woo_conditional_shipping_dynamic_rates', array() );

	foreach ( $rates as $key => $rate ) {
		if ( $key && is_a( $rate, 'WC_Shipping_Rate' ) ) {
			$registered[$key] = $rate->get_label();
		}
	}

	if ( ! empty( $registered ) ) {
		update_option( 'woo_conditional_shipping_dynamic_rates', $registered );
	}

	return $rates;
}, 1, 2 );

/**
 * Add rates as options
 */
add_filter( 'woo_conditional_shipping_method_options', function( $options ) {
	$registered = get_option( 'woo_conditional_shipping_dynamic_rates', array() );

	$options = array();
	
	if ( ! empty( $registered ) ) {
		$options['dynamic_rates'] = array(
			'title' => 'Dynamically detected',
			'options' => array(),
		);

		foreach ( $registered as $key => $title ) {
			$options['dynamic_rates']['options'][$key] = array(
				'title' => $title,
			);
		}
	}

	return $options;
}, 100, 1 );

/**
 * Get correct instance ID
 */
add_filter( 'woo_conditional_shipping_get_instance_id', function( $instance_id, $rate ) {
	if ( is_a( $rate, 'WC_Shipping_Rate' ) && $rate->get_id() ) {
		$instance_id = $rate->get_id();
	}

	return $instance_id;
}, 100, 2 );

/**
 * Get correct instance ID from the shipping method
 */
add_filter( 'woo_conditional_shipping_get_instance_id_from_method', function( $instance_id, $args, $method ) {
	if ( is_array( $args ) && isset( $args['id'] ) ) {
		return $args['id'];
	}

	return $instance_id;
}, 100, 3 );
